get.variables <- function(lprec) {
  .Call(RlpSolve_get_variables, lprec)
}
